@@ -27,31 +27,6 @@ class Domoticz(IPlugin):
 #
 #
 #
-	def devices(self, jsonInput):
-			
-		if jsonInput['outcome']['entities']['wit/location']['value'] :
-			location = jsonInput['outcome']['entities']['wit/location']['value']
-		else:
-			bod = "pas de lieu"
-		
-		
-		if jsonInput['outcome']['entities']['wit/temperature']['value'] :
-			location = jsonInput['outcome']['entities']['wit/temperature']['value']
-		else:
-			bod = "pas de temperature"
-#
-		idex= location + "_" + on_off
-		for rs in self.configuration_plugin['param_dz']:
-			if rs['ids'] == idex :
-				rss = rs
-				bod = rss(boy)
-		#	http://192.168.0.3:8080/json.htm?type=devices&filter=temp&rid=74
-		# parse result : Temp	
-		return {"plugin": "Domoticz",
-			"method": "devices",
-			"body": bod
-		}
-
 	
 	def switchlight(self, jsonInput):
 		
@@ -68,8 +43,8 @@ class Domoticz(IPlugin):
 		idex= location + "_" + on_off
 		#log.msg("WAMP session data received (transport ID %s): %s" % (self._parent._transportid, payload))
 		log.msg("index :  %s" % (idex)		
-		for rs in self.configuration_plugin['param_dz']:
-			if rs['ids'] == idex :
+		for rs in self.configuration_plugin['param_dz']
+			if rs['ids'] == idex
 				bod = rs(boy)
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs[idx],on_off.capitalize()))
 		return {"plugin": "Domoticz",
